### <img src="https://seleniumbase.io/img/sb_icon.png" title="SeleniumBase" width="30" /> SeleniumBase browser extension storage

**The List:**
* disable_csp.zip => Disable Chrome's Content-Security-Policy
